@@ -3,26 +3,28 @@
 #'
 #' @description
 #'
-#' \code{check_collinearity()} checks regression models for
-#'   multicollinearity by calculating the variance inflation factor (VIF).
-#'   \code{multicollinearity()} is an alias for \code{check_collinearity()}.
-#'   (When printed, VIF are also translated to Tolerance values, where
-#'   \code{tolerance = 1/vif}.)
+#'  `check_collinearity()` checks regression models for
+#'  multicollinearity by calculating the variance inflation factor (VIF).
+#'  `multicollinearity()` is an alias for `check_collinearity()`.
+#'  (When printed, VIF are also translated to tolerance values, where
+#'  `tolerance = 1/vif`.) `check_concurvity()` is a wrapper around
+#'  `mgcv::concurvity()`, and can be considered as a collinearity check
+#'  for smooth terms in GAMs.
 #'
-#' @param x A model object (that should at least respond to \code{vcov()},
-#'  and if possible, also to \code{model.matrix()} - however, it also should
-#'  work without \code{model.matrix()}).
+#' @param x A model object (that should at least respond to `vcov()`,
+#'  and if possible, also to `model.matrix()` - however, it also should
+#'  work without `model.matrix()`).
 #' @param component For models with zero-inflation component, multicollinearity
 #'  can be checked for the conditional model (count component,
-#'  \code{component = "conditional"} or \code{component = "count"}),
-#'  zero-inflation component (\code{component = "zero_inflated"} or
-#'  \code{component = "zi"}) or both components (\code{component = "all"}).
-#'  Following model-classes are currently supported: \code{hurdle},
-#'  \code{zeroinfl}, \code{zerocount}, \code{MixMod} and \code{glmmTMB}.
+#'  `component = "conditional"` or `component = "count"`),
+#'  zero-inflation component (`component = "zero_inflated"` or
+#'  `component = "zi"`) or both components (`component = "all"`).
+#'  Following model-classes are currently supported: `hurdle`,
+#'  `zeroinfl`, `zerocount`, `MixMod` and `glmmTMB`.
 #' @param verbose Toggle off warnings or messages.
 #' @param ... Currently not used.
 #'
-#' @return A data frame with three columns: The name of the model term, the
+#' @return A data frame with four columns: The name of the model term, the
 #'   variance inflation factor and the factor by which the standard error
 #'   is increased due to possible correlation with other terms.
 #'
@@ -31,8 +33,8 @@
 #' \subsection{Multicollinearity}{
 #'   Multicollinearity should not be confused with a raw strong correlation
 #'   between predictors. What matters is the association between one or more
-#'   predictor variables, \emph{conditional on the other variables in the
-#'   model}. In a nutshell, multicollinearity means that once you know the
+#'   predictor variables, *conditional on the other variables in the
+#'   model*. In a nutshell, multicollinearity means that once you know the
 #'   effect of one predictor, the value of knowing the other predictor is rather
 #'   low. Thus, one of the predictors doesn't help much in terms of better
 #'   understanding the model or predicting the outcome. As a consequence, if
@@ -58,7 +60,7 @@
 #'   correlation of that predictor with other predictors. A value between 5 and
 #'   10 indicates a moderate correlation, while VIF values larger than 10 are a
 #'   sign for high, not tolerable correlation of model predictors (\cite{James
-#'   et al. 2013}). The \emph{Increased SE} column in the output indicates how
+#'   et al. 2013}). The *Increased SE* column in the output indicates how
 #'   much larger the standard error is due to the association with other
 #'   predictors conditional on the remaining variables in the model.
 #' }
@@ -71,11 +73,25 @@
 #'   terms \cite{(Francoeur 2013)}.
 #' }
 #'
+#' \subsection{Concurvity for Smooth Terms in Generalized Additive Models}{
+#'   `check_concurvity()` is a wrapper around `mgcv::concurvity()`, and can be
+#'   considered as a collinearity check for smooth terms in GAMs.
+#'   \dQuote{Concurvity occurs when some smooth term in a model could be
+#'   approximated by one or more of the other smooth terms in the model.} (see
+#'   `?mgcv::concurvity`). `check_concurvity()` returns a column named _VIF_,
+#'   which is the "worst" measure. While `mgcv::concurvity()` range between
+#'   0 and 1, the _VIF_ value is `1 / (1 - worst)`, to make interpretation
+#'   comparable to classical VIF values, i.e. `1` indicates no problems, while
+#'   higher values indicate increasing lack of identifiability. The _VIF proportion_
+#'   column equals the "estimate" column from `mgcv::concurvity()`, ranging
+#'   from 0 (no problem) to 1 (total lack of identifiability).
+#' }
+#'
 #' @references
 #'   \itemize{
 #'   \item Francoeur, R. B. (2013). Could Sequential Residual Centering Resolve
 #'   Low Sensitivity in Moderated Regression? Simulations and Cancer Symptom
-#'   Clusters. Open Journal of Statistics, 03(06), 24–44.
+#'   Clusters. Open Journal of Statistics, 03(06), 24-44.
 #'
 #'   \item James, G., Witten, D., Hastie, T., & Tibshirani, R. (eds.). (2013).
 #'   An introduction to statistical learning: with applications in R. New York:
@@ -85,10 +101,10 @@
 #'   examples in R and Stan. 2nd edition. Chapman and Hall/CRC.
 #'
 #'   \item Vanhove, J. (2019). Collinearity isn't a disease that needs curing.
-#'   \href{https://janhove.github.io/analysis/2019/09/11/collinearity}{webpage}
+#'   [webpage](https://janhove.github.io/analysis/2019/09/11/collinearity)
 #'   }
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/performance.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @examples
 #' m <- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
@@ -110,37 +126,95 @@ check_collinearity <- function(x, ...) {
 multicollinearity <- check_collinearity
 
 
+
+# default ------------------------------
+
 #' @rdname check_collinearity
 #' @export
 check_collinearity.default <- function(x, verbose = TRUE, ...) {
   .check_collinearity(x, component = "conditional", verbose = verbose)
 }
 
+
+
+# methods -------------------------------------------
+
 #' @export
-check_collinearity.afex_aov <- function(x, verbose = TRUE, ...) {
+print.check_collinearity <- function(x, ...) {
+  insight::print_color("# Check for Multicollinearity\n", "blue")
 
-  # for now, give error when no aov-slot is present.
-  # see https://github.com/easystats/performance/issues/326
-
-  if (is.null(x$aov)) {
-    stop(
-      insight::format_message("Can't check for multicollinearity when aov-slot is missing.",
-                              "Please refit the model with 'include_aov = TRUE' or use a mixed model instead."),
-      call. = FALSE
-    )
+  if ("Component" %in% colnames(x)) {
+    comp <- split(x, x$Component)
+    for (i in 1:length(comp)) {
+      cat(paste0("\n* ", comp[[i]]$Component[1], " component:\n"))
+      .print_collinearity(comp[[i]][, 1:3])
+    }
+  } else {
+    .print_collinearity(x)
   }
 
-  f <- paste(row.names(x$anova_table), collapse = "+")
-  f <- paste0(insight::find_response(x), "~", f)
-  # f <- insight::find_formula(x)[[1]]
-  # f <- Reduce(paste, deparse(f))
-  # f <- sub("\\+\\s*Error\\(.*\\)$", "", f)
-  # f <- as.formula(f)
+  invisible(x)
+}
+
+
+#' @export
+plot.check_collinearity <- function(x, ...) {
+  insight::check_if_installed("see", "to plot collinearity-check")
+  NextMethod()
+}
+
+
+.print_collinearity <- function(x) {
+  vifs <- x$VIF
+  x$Tolerance <- 1 / x$VIF
+
+  x$VIF <- sprintf("%.2f", x$VIF)
+  x$SE_factor <- sprintf("%.2f", x$SE_factor)
+  x$Tolerance <- sprintf("%.2f", x$Tolerance)
+
+  colnames(x)[3] <- "Increased SE"
+
+  low_corr <- which(vifs < 5)
+  if (length(low_corr)) {
+    cat("\n")
+    insight::print_color("Low Correlation\n\n", "green")
+    print.data.frame(x[low_corr, ], row.names = FALSE)
+  }
+
+  mid_corr <- which(vifs >= 5 & vifs < 10)
+  if (length(mid_corr)) {
+    cat("\n")
+    insight::print_color("Moderate Correlation\n\n", "yellow")
+    print.data.frame(x[mid_corr, ], row.names = FALSE)
+  }
+
+  high_corr <- which(vifs >= 10)
+  if (length(high_corr)) {
+    cat("\n")
+    insight::print_color("High Correlation\n\n", "red")
+    print.data.frame(x[high_corr, ], row.names = FALSE)
+  }
+}
+
+
+
+# other classes ----------------------------------
+
+#' @export
+check_collinearity.afex_aov <- function(x, verbose = TRUE, ...) {
+  if (length(attr(x, "within")) == 0L) {
+    return(check_collinearity(x$lm, verbose = verbose, ...))
+  }
+
+  f <- insight::find_formula(x)[[1]]
+  f <- Reduce(paste, deparse(f))
+  f <- sub("\\+\\s*Error\\(.*\\)$", "", f)
+  f <- stats::as.formula(f)
 
   d <- insight::get_data(x, verbose = verbose)
   is_num <- sapply(d, is.numeric)
   d[is_num] <- sapply(d[is_num], scale, center = TRUE, scale = FALSE)
-  is_fac <- sapply(d, is.factor) | sapply(d, is.character)
+  is_fac <- !is_num
   contrs <- lapply(is_fac, function(...) stats::contr.sum)[is_fac]
 
   if (verbose) {
@@ -154,6 +228,16 @@ check_collinearity.afex_aov <- function(x, verbose = TRUE, ...) {
   )))
 }
 
+#' @export
+check_collinearity.BFBayesFactor <- function(x, verbose = TRUE, ...) {
+  if (!insight::is_model(x)) {
+    stop("Collinearity only applicable to regression models.")
+  }
+
+  f <- insight::find_formula(x)[[1]]
+  d <- insight::get_data(x)
+  check_collinearity(stats::lm(f, d))
+}
 
 # mfx models -------------------------------
 
@@ -188,11 +272,8 @@ check_collinearity.betamfx <- check_collinearity.logitor
 
 
 
-
-
 # zi-models -------------------------------------
 
-
 #' @rdname check_collinearity
 #' @export
 check_collinearity.glmmTMB <- function(x,
@@ -204,7 +285,6 @@ check_collinearity.glmmTMB <- function(x,
 }
 
 
-
 #' @export
 check_collinearity.MixMod <- function(x,
                                       component = c("all", "conditional", "count", "zi", "zero_inflated"),
@@ -215,7 +295,6 @@ check_collinearity.MixMod <- function(x,
 }
 
 
-
 #' @export
 check_collinearity.hurdle <- function(x,
                                       component = c("all", "conditional", "count", "zi", "zero_inflated"),
@@ -226,7 +305,6 @@ check_collinearity.hurdle <- function(x,
 }
 
 
-
 #' @export
 check_collinearity.zeroinfl <- function(x,
                                         component = c("all", "conditional", "count", "zi", "zero_inflated"),
@@ -237,7 +315,6 @@ check_collinearity.zeroinfl <- function(x,
 }
 
 
-
 #' @export
 check_collinearity.zerocount <- function(x,
                                          component = c("all", "conditional", "count", "zi", "zero_inflated"),
@@ -249,6 +326,8 @@ check_collinearity.zerocount <- function(x,
 
 
 
+# utilities ---------------------------------
+
 .check_collinearity_zi_model <- function(x, component, verbose = TRUE) {
   if (component == "count") component <- "conditional"
   if (component == "zi") component <- "zero_inflated"
@@ -284,13 +363,12 @@ check_collinearity.zerocount <- function(x,
 
 
 
-
 .check_collinearity <- function(x, component, verbose = TRUE) {
   v <- insight::get_varcov(x, component = component, verbose = FALSE)
   assign <- .term_assignments(x, component, verbose = verbose)
 
   # any assignment found?
-  if (is.null(assign)) {
+  if (is.null(assign) || all(is.na(assign))) {
     if (verbose) {
       warning(insight::format_message(sprintf("Could not extract model terms for the %s component of the model.", component), call. = FALSE))
     }
@@ -369,29 +447,30 @@ check_collinearity.zerocount <- function(x,
 
   structure(
     class = c("check_collinearity", "see_check_collinearity", "data.frame"),
-    .remove_backticks_from_parameter_names(
+    insight::text_remove_backticks(
       data.frame(
         Term = terms,
         VIF = result,
         SE_factor = sqrt(result),
         stringsAsFactors = FALSE
-      )
+      ),
+      column = "Term"
     ),
-    data = .remove_backticks_from_parameter_names(
+    data = insight::text_remove_backticks(
       data.frame(
         Term = terms,
         VIF = result,
         SE_factor = sqrt(result),
         Component = component,
         stringsAsFactors = FALSE
-      )
+      ),
+      column = "Term"
     )
   )
 }
 
 
 
-
 .term_assignments <- function(x, component, verbose = TRUE) {
   tryCatch(
     {
@@ -428,7 +507,6 @@ check_collinearity.zerocount <- function(x,
 
 
 
-
 .find_term_assignment <- function(x, component, verbose = TRUE) {
   pred <- insight::find_predictors(x)[[component]]
 
@@ -450,8 +528,14 @@ check_collinearity.zerocount <- function(x,
     }
   }))
 
+  if (insight::is_gam_model(x)) {
+    model_params <- as.vector(unlist(unlist(insight::find_parameters(x)[c(component, "smooth_terms")])))
+  } else {
+    model_params <- insight::find_parameters(x)[[component]]
+  }
+
   as.numeric(names(parms)[match(
-    insight::clean_names(insight::find_parameters(x)[[component]]),
+    insight::clean_names(model_params),
     parms
   )])
 }
