@@ -17,7 +17,7 @@
 #' should be reconsidered. Since it is difficult to exactly predict the correct
 #' model family, consider this function as somewhat experimental.
 #'
-#' @param model Typically, a model (that should response to \code{residuals()}).
+#' @param model Typically, a model (that should response to `residuals()`).
 #'   May also be a numeric vector.
 #'
 #' @note This function is somewhat experimental and might be improved in future
@@ -25,7 +25,7 @@
 #'   theoretical aspects and other information about the data and the model.
 #'   \cr \cr
 #'   There is also a
-#'   \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method}
+#'   [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
 #'   implemented in the
 #'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
@@ -33,23 +33,24 @@
 #'
 #' This function uses an internal random forest model to classify the
 #' distribution from a model-family. Currently, following distributions are
-#' trained (i.e. results of \code{check_distribution()} may be one of the
-#' following): \code{"bernoulli"}, \code{"beta"}, \code{"beta-binomial"},
-#' \code{"binomial"}, \code{"chi"}, \code{"exponential"}, \code{"F"},
-#' \code{"gamma"}, \code{"lognormal"}, \code{"normal"}, \code{"negative
-#' binomial"}, \code{"negative binomial (zero-inflated)"}, \code{"pareto"},
-#' \code{"poisson"}, \code{"poisson (zero-inflated)"}, \code{"uniform"} and
-#' \code{"weibull"}.
+#' trained (i.e. results of `check_distribution()` may be one of the
+#' following): `"bernoulli"`, `"beta"`, `"beta-binomial"`,
+#' `"binomial"`, `"chi"`, `"exponential"`, `"F"`,
+#' `"gamma"`, `"lognormal"`, `"normal"`, `"negative
+#' binomial"`, `"negative binomial (zero-inflated)"`, `"pareto"`,
+#' `"poisson"`, `"poisson (zero-inflated)"`, `"uniform"` and
+#' `"weibull"`.
 #' \cr \cr
 #' Note the similarity between certain distributions according to shape, skewness,
 #' etc. Thus, the predicted distribution may not be perfectly representing the
 #' distributional family of the underlying fitted model, or the response value.
 #' \cr \cr
-#' There is a \code{plot()} method, which shows the probabilities of all predicted
+#' There is a `plot()` method, which shows the probabilities of all predicted
 #' distributions, however, only if the probability is greater than zero.
 #'
 #' @examples
-#' if (require("lme4") && require("parameters") && require("see") && require("patchwork")) {
+#' if (require("lme4") && require("parameters") &&
+#'   require("see") && require("patchwork") && require("randomForest")) {
 #'   data(sleepstudy)
 #'
 #'   model <<- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
@@ -61,26 +62,9 @@ check_distribution <- function(model) {
   UseMethod("check_distribution")
 }
 
-#' @export
-check_distribution.numeric <- function(model) {
-  insight::check_if_installed("randomForest")
 
-  dat <- .extract_features(model)
-  dist <- as.data.frame(t(stats::predict(classify_distribution, dat, type = "prob")))
-
-  out <- data.frame(
-    Distribution = rownames(dist),
-    p_Vector = dist[[1]],
-    stringsAsFactors = FALSE,
-    row.names = NULL
-  )
-
-  class(out) <- unique(c("check_distribution_numeric", "see_check_distribution_numeric", class(out)))
-  attr(out, "data") <- model
-
-  out
-}
 
+# default -----------------------------
 
 #' @export
 check_distribution.default <- function(model) {
@@ -119,6 +103,86 @@ check_distribution.default <- function(model) {
 
 
 
+# methods --------------------------
+
+#' @export
+print.check_distribution <- function(x, ...) {
+  insight::print_color("# Distribution of Model Family\n\n", "blue")
+
+  x1 <- x[order(x$p_Residuals, decreasing = TRUE)[1:3], c(1, 2)]
+  x1 <- x1[x1$p_Residuals > 0, ]
+  x1$p_Residuals <- sprintf("%g%%", round(100 * x1$p_Residuals))
+  colnames(x1) <- c("Distribution", "Probability")
+
+  insight::print_color("Predicted Distribution of Residuals\n\n", "red")
+  print.data.frame(x1, row.names = FALSE, ...)
+
+  x2 <- x[order(x$p_Response, decreasing = TRUE)[1:3], c(1, 3)]
+  x2 <- x2[x2$p_Response > 0, ]
+  x2$p_Response <- sprintf("%g%%", round(100 * x2$p_Response))
+  colnames(x2) <- c("Distribution", "Probability")
+
+  insight::print_color("\nPredicted Distribution of Response\n\n", "red")
+  print.data.frame(x2, row.names = FALSE, ...)
+  invisible(x)
+}
+
+
+#' @export
+print.check_distribution_numeric <- function(x, ...) {
+  insight::print_color("# Predicted Distribution of Vector\n\n", "blue")
+
+  x1 <- x[order(x$p_Vector, decreasing = TRUE)[1:3], c(1, 2)]
+  x1 <- x1[x1$p_Vector > 0, ]
+  x1$p_Vector <- sprintf("%g%%", round(100 * x1$p_Vector))
+  colnames(x1) <- c("Distribution", "Probability")
+
+  print.data.frame(x1, row.names = FALSE, ...)
+  invisible(x)
+}
+
+
+#' @export
+plot.check_distribution <- function(x, ...) {
+  insight::check_if_installed("see", "to plot predicted distributions")
+  NextMethod()
+}
+
+
+#' @export
+plot.check_distribution_numeric <- function(x, ...) {
+  insight::check_if_installed("see", "to plot predicted distributions")
+  NextMethod()
+}
+
+
+
+# other classes -------------------
+
+#' @export
+check_distribution.numeric <- function(model) {
+  insight::check_if_installed("randomForest")
+
+  dat <- .extract_features(model)
+  dist <- as.data.frame(t(stats::predict(classify_distribution, dat, type = "prob")))
+
+  out <- data.frame(
+    Distribution = rownames(dist),
+    p_Vector = dist[[1]],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  class(out) <- unique(c("check_distribution_numeric", "see_check_distribution_numeric", class(out)))
+  attr(out, "data") <- model
+
+  out
+}
+
+
+
+# utilities -----------------------------
+
 .extract_features <- function(x) {
   data.frame(
     "SD" = stats::sd(x),
@@ -142,6 +206,7 @@ check_distribution.default <- function(model) {
 }
 
 
+
 .is_integer <- function(x) {
   tryCatch(
     expr = {
