@@ -5,18 +5,18 @@
 #'
 #' @param x A linear model or an ANOVA object.
 #' @param method Name of the method (underlying test) that should be performed
-#'   to check the homogeneity of variances. May either be \code{"levene"} for
-#'   Levene's Test for Homogeneity of Variance, \code{"bartlett"} for the
+#'   to check the homogeneity of variances. May either be `"levene"` for
+#'   Levene's Test for Homogeneity of Variance, `"bartlett"` for the
 #'   Bartlett test (assuming normal distributed samples or groups),
-#'   \code{"fligner"} for the Fligner-Killeen test (rank-based, non-parametric
-#'   test), or \code{"auto"}. In the latter case, Bartlett test is used if the
+#'   `"fligner"` for the Fligner-Killeen test (rank-based, non-parametric
+#'   test), or `"auto"`. In the latter case, Bartlett test is used if the
 #'   model response is normal distributed, else Fligner-Killeen test is used.
-#' @param ... Arguments passed down to \code{car::leveneTest()}.
+#' @param ... Arguments passed down to `car::leveneTest()`.
 #'
 #' @return Invisibly returns the p-value of the test statistics. A p-value <
 #'   0.05 indicates a significant difference in the variance between the groups.
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/performance.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @examples
 #' model <<- lm(len ~ supp + dose, data = ToothGrowth)
@@ -33,6 +33,9 @@ check_homogeneity <- function(x, method = c("bartlett", "fligner", "levene", "au
 }
 
 
+
+# default -------------------------
+
 #' @export
 check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "levene", "auto"), ...) {
   method <- match.arg(method)
@@ -90,35 +93,53 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
     "levene" = "Levene's Test"
   )
 
-  if (is.na(p.val)) {
-    warning(paste0("Could not perform ", method.string, "."), call. = FALSE)
-    invisible(NULL)
-  } else if (p.val < 0.05) {
-    insight::print_color(sprintf("Warning: Variances differ between groups (%s, p = %.3f).\n", method.string, p.val), "red")
-  } else {
-    insight::print_color(sprintf("OK: Variances in each of the groups are the same (%s, p = %.3f).\n", method.string, p.val), "green")
-  }
-
   attr(p.val, "object_name") <- deparse(substitute(x), width.cutoff = 500)
   attr(p.val, "method") <- method.string
   class(p.val) <- unique(c("check_homogeneity", "see_check_homogeneity", class(p.val)))
 
-  invisible(p.val)
+  p.val
 }
 
+
+
+# methods -----------------------
+
+#' @export
+print.check_homogeneity <- function(x, ...) {
+  method.string <- attributes(x)$method
+  if (is.na(x)) {
+    warning(paste0("Could not perform ", method.string, "."), call. = FALSE)
+    invisible(NULL)
+  } else if (x < 0.05) {
+    insight::print_color(sprintf("Warning: Variances differ between groups (%s, p = %.3f).\n", method.string, x), "red")
+  } else {
+    insight::print_color(sprintf("OK: There is not clear evidence for different variances across groups (%s, p = %.3f).\n", method.string, x), "green")
+  }
+  invisible(x)
+}
+
+
+#' @export
+plot.check_homogeneity <- function(x, ...) {
+  insight::check_if_installed("see", "for homogeneity plots")
+  NextMethod()
+}
+
+
+
+# other classes -----------------------------
+
 #' @rdname check_homogeneity
 #' @export
 check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
-  if (!requireNamespace("car")) {
-    stop("car required for this function to work.")
-  }
+  insight::check_if_installed("car")
 
   if (tolower(method) != "levene") {
     message("Only Levene's test for homogeneity supported for afex_aov")
   }
 
   if (length(attr(x, "between")) == 0) {
-    stop("Levene test is only aplicable to ANOVAs with between-subjects factors.")
+    stop("Levene test is only aplicable to ANOVAs with between-subjects factors.", call. = FALSE)
   }
 
   data <- x$data$long # Use this to also get id column
@@ -143,20 +164,9 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
 
   p.val <- test[1, "Pr(>F)"]
 
-  method.string <- "Levene's Test"
-
-  if (is.na(p.val)) {
-    warning(paste0("Could not perform ", method.string, "."), call. = FALSE)
-    invisible(NULL)
-  } else if (p.val < 0.05) {
-    insight::print_color(sprintf("Warning: Variances differ between groups (%s, p = %.3f).\n", method.string, p.val), "red")
-  } else {
-    insight::print_color(sprintf("OK: Variances in each of the groups are the same (%s, p = %.3f).\n", method.string, p.val), "green")
-  }
-
   attr(p.val, "object_name") <- deparse(substitute(x), width.cutoff = 500)
-  attr(p.val, "method") <- method.string
+  attr(p.val, "method") <- "Levene's Test"
   class(p.val) <- unique(c("check_homogeneity", "see_check_homogeneity", class(p.val)))
 
-  invisible(p.val)
+  p.val
 }
