@@ -4,25 +4,25 @@
 #' @description Check model for (non-)normality of residuals.
 #'
 #' @param x A model object.
-#' @param effects Should normality for residuals (\code{"fixed"}) or random
-#'   effects (\code{"random"}) be tested? Only applies to mixed-effects models.
+#' @param effects Should normality for residuals (`"fixed"`) or random
+#'   effects (`"random"`) be tested? Only applies to mixed-effects models.
 #'   May be abbreviated.
 #' @param ... Currently not used.
 #'
-#' @return Invisibly returns the p-value of the test statistics. A p-value
-#' < 0.05 indicates a significant deviation from normal distribution
+#' @return The p-value of the test statistics. A p-value < 0.05 indicates a
+#'   significant deviation from normal distribution.
 #'
-#' @note For mixed-effects models, studentized residuals, and \emph{not}
+#' @note For mixed-effects models, studentized residuals, and *not*
 #'   standardized residuals, are used for the test. There is also a
-#'   \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method}
+#'   [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
 #'    implemented in the
 #'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
-#' @details \code{check_normality()} calls \code{stats::shapiro.test}
-#' and checks the standardized residuals (or Studentized residuals for mixed
-#' models) for normal distribution. Note that this formal test almost always
-#' yields significant results for the distribution of residuals and visual
-#' inspection (e.g. Q-Q plots) are preferable.
+#' @details `check_normality()` calls `stats::shapiro.test` and checks the
+#' standardized residuals (or Studentized residuals for mixed models) for
+#' normal distribution. Note that this formal test almost always yields
+#' significant results for the distribution of residuals and visual inspection
+#' (e.g. Q-Q plots) are preferable.
 #'
 #' @examples
 #' m <<- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
@@ -46,6 +46,9 @@ check_normality <- function(x, ...) {
 }
 
 
+
+# default -------------------------
+
 #' @export
 check_normality.default <- function(x, ...) {
   # valid model?
@@ -57,16 +60,41 @@ check_normality.default <- function(x, ...) {
   # check for normality of residuals
   p.val <- .check_normality(stats::rstandard(x), x)
 
-  attr(p.val, "object_name") <- .safe_deparse(substitute(x))
+  attr(p.val, "data") <- x
+  attr(p.val, "object_name") <- insight::safe_deparse(substitute(x))
   attr(p.val, "effects") <- "fixed"
   class(p.val) <- unique(c("check_normality", "see_check_normality", class(p.val)))
 
-  invisible(p.val)
+  p.val
 }
 
 
 
+# methods ----------------------
 
+#' @export
+plot.check_normality <- function(x, ...) {
+  insight::check_if_installed("see", "for residual plots")
+  NextMethod()
+}
+
+
+#' @export
+print.check_normality <- function(x, ...) {
+  pstring <- insight::format_p(x)
+  type <- attributes(x)$type
+
+  if (x < 0.05) {
+    insight::print_color(sprintf("Warning: Non-normality of %s detected (%s).\n", type, pstring), "red")
+  } else {
+    insight::print_color(sprintf("OK: %s appear as normally distributed (%s).\n", type, pstring), "green")
+  }
+  invisible(x)
+}
+
+
+
+# other classes --------------------
 
 # mixed models ---------------------
 
@@ -120,11 +148,12 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
     p.val <- .check_normality(stats::rstudent(x), x)
   }
 
-  attr(p.val, "object_name") <- .safe_deparse(substitute(x))
+  attr(p.val, "data") <- x
+  attr(p.val, "object_name") <- insight::safe_deparse(substitute(x))
   attr(p.val, "effects") <- effects
   class(p.val) <- unique(c("check_normality", "see_check_normality", class(p.val)))
 
-  invisible(p.val)
+  p.val
 }
 
 
@@ -141,17 +170,21 @@ check_normality.afex_aov <- function(x, ...) {
   r <- suppressMessages(stats::residuals(x, append = FALSE))
   p.val <- .check_normality(r, x)
 
-  attr(p.val, "object_name") <- .safe_deparse(substitute(x))
+  attr(p.val, "data") <- x
+  attr(p.val, "object_name") <- insight::safe_deparse(substitute(x))
   class(p.val) <- unique(c("check_normality", "see_check_normality", class(p.val)))
 
   invisible(p.val)
 }
 
 
+#' @export
+check_normality.BFBayesFactor <- check_normality.afex_aov
+
+
 
 # helper ---------------------
 
-
 .check_normality <- function(x, model, type = "residuals") {
   ts <- tryCatch(
     {
@@ -171,15 +204,8 @@ check_normality.afex_aov <- function(x, ...) {
     return(NULL)
   }
 
-  # format p-value
-  p.val <- ts$p.value
-  pstring <- insight::format_p(p.val)
+  out <- ts$p.value
+  attr(out, "type") <- type
 
-  if (p.val < 0.05) {
-    insight::print_color(sprintf("Warning: Non-normality of %s detected (%s).\n", type, pstring), "red")
-  } else {
-    insight::print_color(sprintf("OK: %s appear as normally distributed (%s).\n", type, pstring), "green")
-  }
-
-  p.val
+  out
 }
