@@ -237,20 +237,6 @@ icc <- function(model, by_group = FALSE, tolerance = 1e-05) {
 
 
 
-#' @export
-as.data.frame.icc <- function(x, row.names = NULL, optional = FALSE, ...) {
-  data.frame(
-    ICC_adjusted = x$ICC_adjusted,
-    ICC_conditional = x$ICC_conditional,
-    stringsAsFactors = FALSE,
-    row.names = row.names,
-    optional = optional,
-    ...
-  )
-}
-
-
-
 #' @param ... Arguments passed down to `brms::posterior_predict()`.
 #' @inheritParams icc
 #' @rdname icc
@@ -322,3 +308,139 @@ variance_decomposition <- function(model,
 
   result
 }
+
+
+
+# methods ------------------------------
+
+#' @export
+as.data.frame.icc <- function(x, row.names = NULL, optional = FALSE, ...) {
+  data.frame(
+    ICC_adjusted = x$ICC_adjusted,
+    ICC_conditional = x$ICC_conditional,
+    stringsAsFactors = FALSE,
+    row.names = row.names,
+    optional = optional,
+    ...
+  )
+}
+
+
+#' @export
+print.icc <- function(x, digits = 3, ...) {
+  insight::print_color("# Intraclass Correlation Coefficient\n\n", "blue")
+
+  out <- paste0(c(
+    sprintf("     Adjusted ICC: %.*f", digits, x$ICC_adjusted),
+    sprintf("  Conditional ICC: %.*f", digits, x$ICC_conditional)
+  ),
+  collapse = "\n"
+  )
+
+  cat(out)
+  cat("\n")
+  invisible(x)
+}
+
+
+#' @export
+print.icc_by_group <- function(x, digits = 3, ...) {
+  insight::print_color("# ICC by Group\n\n", "blue")
+  cat(insight::export_table(x, digits = digits))
+  invisible(x)
+}
+
+
+#' @export
+print.icc_decomposed <- function(x, digits = 2, ...) {
+  # print model information
+  cat("# Random Effect Variances and ICC\n\n")
+
+  reform <- attr(x, "re.form", exact = TRUE)
+  if (is.null(reform)) {
+    reform <- "all random effects"
+  } else {
+    reform <- insight::safe_deparse(reform)
+  }
+
+  cat(sprintf("Conditioned on: %s\n\n", reform))
+
+  prob <- attr(x, "ci", exact = TRUE)
+
+  cat(insight::print_color("## Variance Ratio (comparable to ICC)\n", "blue"))
+
+  icc.val <- sprintf("%.*f", digits, x$ICC_decomposed)
+
+  ci.icc.lo <- sprintf("%.*f", digits, x$ICC_CI[1])
+  ci.icc.hi <- sprintf("%.*f", digits, x$ICC_CI[2])
+
+  # ICC
+  cat(sprintf(
+    "Ratio: %s  CI %i%%: [%s %s]\n",
+    icc.val,
+    as.integer(round(prob * 100)),
+    ci.icc.lo,
+    ci.icc.hi
+  ))
+
+  cat(insight::print_color("\n## Variances of Posterior Predicted Distribution\n", "blue"))
+
+  null.model <- sprintf("%.*f", digits, attr(x, "var_rand_intercept", exact = TRUE))
+
+  ci.null <- attr(x, "ci.var_rand_intercept", exact = TRUE)
+  ci.null.lo <- sprintf("%.*f", digits, ci.null$CI_low)
+  ci.null.hi <- sprintf("%.*f", digits, ci.null$CI_high)
+
+  full.model <- sprintf("%.*f", digits, attr(x, "var_total", exact = TRUE))
+
+  ci.full <- attr(x, "ci.var_total", exact = TRUE)
+  ci.full.lo <- sprintf("%.*f", digits, ci.full$CI_low)
+  ci.full.hi <- sprintf("%.*f", digits, ci.full$CI_high)
+
+  ml <- max(nchar(null.model), nchar(full.model))
+  ml.ci <- max(nchar(ci.full.lo), nchar(ci.null.lo))
+  mh.ci <- max(nchar(ci.full.hi), nchar(ci.null.hi))
+
+  # Conditioned on fixed effects
+  cat(sprintf(
+    "Conditioned on fixed effects: %*s  CI %i%%: [%*s %*s]\n",
+    ml,
+    null.model,
+    as.integer(round(prob * 100)),
+    ml.ci,
+    ci.null.lo,
+    mh.ci,
+    ci.null.hi
+  ))
+
+  # Conditioned on random effects
+  cat(sprintf(
+    "Conditioned on rand. effects: %*s  CI %i%%: [%*s %*s]\n",
+    ml,
+    full.model,
+    as.integer(round(prob * 100)),
+    ml.ci,
+    ci.full.lo,
+    mh.ci,
+    ci.full.hi
+  ))
+
+  cat(insight::print_color("\n## Difference in Variances\n", "red"))
+
+  res <- sprintf("%.*f", digits, attr(x, "var_residual", exact = TRUE))
+
+  ci.res <- attr(x, "ci.var_residual", exact = TRUE)
+  ci.res.lo <- sprintf("%.*f", digits, ci.res$CI_low)
+  ci.res.hi <- sprintf("%.*f", digits, ci.res$CI_high)
+
+  # ICC
+  cat(sprintf(
+    "Difference: %s  CI %i%%: [%s %s]\n",
+    res,
+    as.integer(round(prob * 100)),
+    ci.res.lo,
+    ci.res.hi
+  ))
+
+  invisible(x)
+}
