@@ -4,70 +4,71 @@
 #' \pkg{lavaan} package.
 #'
 #' @param model A \pkg{lavaan} model.
-#' @param metrics Can be \code{"all"} or a character vector of metrics to be
-#'   computed (some of \code{c("Chisq", "Chisq_DoF", "Chisq_p", "Baseline",
-#'   "Baseline_DoF", "Baseline_p", "CFI", "TLI", "NNFI", "RFI", "NFI", "PNFI",
-#'   "IFI", "RNI", "Loglikelihood", "AIC", "BIC", "BIC_adjusted", "RMSEA",
-#'   "SMRM")}).
+#' @param metrics Can be `"all"` or a character vector of metrics to be
+#'   computed (some of `c("Chi2", "Chi2_df", "p_Chi2", "Baseline",
+#'   "Baseline_df", "p_Baseline", "GFI", "AGFI", "NFI", "NNFI", "CFI",
+#'   "RMSEA", "RMSEA_CI_low", "RMSEA_CI_high", "p_RMSEA", "RMR", "SRMR",
+#'   "RFI", "PNFI", "IFI", "RNI", "Loglikelihood", "AIC", "BIC",
+#'   "BIC_adjusted")`).
 #' @param verbose Toggle off warnings.
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @return A data frame (with one row) and one column per "index" (see
-#'   \code{metrics}).
+#'   `metrics`).
 #'
 #' @details \subsection{Indices of fit}{
 #' \itemize{
-#'    \item \strong{Chisq}: The model Chi-squared assesses overall fit and the
+#'    \item **Chisq**: The model Chi-squared assesses overall fit and the
 #'    discrepancy between the sample and fitted covariance matrices. Its p-value
 #'    should be > .05 (i.e., the hypothesis of a perfect fit cannot be
 #'    rejected). However, it is quite sensitive to sample size.
 #'
-#'    \item \strong{GFI/AGFI}: The (Adjusted) Goodness of Fit is the proportion
+#'    \item **GFI/AGFI**: The (Adjusted) Goodness of Fit is the proportion
 #'    of variance accounted for by the estimated population covariance.
 #'    Analogous to R2. The GFI and the AGFI should be > .95 and > .90,
 #'    respectively.
 #'
-#'    \item \strong{NFI/NNFI/TLI}: The (Non) Normed Fit Index. An NFI of 0.95,
+#'    \item **NFI/NNFI/TLI**: The (Non) Normed Fit Index. An NFI of 0.95,
 #'    indicates the model of interest improves the fit by 95\% relative to the
 #'    null model. The NNFI (also called the Tucker Lewis index; TLI) is
 #'    preferable for smaller samples. They should be > .90 (Byrne, 1994) or >
 #'    .95 (Schumacker & Lomax, 2004).
 #'
-#'    \item \strong{CFI}: The Comparative Fit Index is a revised form of NFI.
+#'    \item **CFI**: The Comparative Fit Index is a revised form of NFI.
 #'    Not very sensitive to sample size (Fan, Thompson, & Wang, 1999). Compares
 #'    the fit of a target model to the fit of an independent, or null, model. It
 #'    should be > .90.
 #'
-#'    \item \strong{RMSEA}: The Root Mean Square Error of Approximation is a
+#'    \item **RMSEA**: The Root Mean Square Error of Approximation is a
 #'    parsimony-adjusted index. Values closer to 0 represent a good fit. It
 #'    should be < .08 or < .05. The p-value printed with it tests the hypothesis
 #'    that RMSEA is less than or equal to .05 (a cutoff sometimes used for good
 #'    fit), and thus should be not significant.
 #'
-#'    \item \strong{RMR/SRMR}: the (Standardized) Root Mean Square Residual
+#'    \item **RMR/SRMR**: the (Standardized) Root Mean Square Residual
 #'    represents the square-root of the difference between the residuals of the
 #'    sample covariance matrix and the hypothesized model. As the RMR can be
 #'    sometimes hard to interpret, better to use SRMR. Should be < .08.
 #'
-#'    \item \strong{RFI}: the Relative Fit Index, also known as RHO1, is not
+#'    \item **RFI**: the Relative Fit Index, also known as RHO1, is not
 #'    guaranteed to vary from 0 to 1. However, RFI close to 1 indicates a good
 #'    fit.
 #'
-#'    \item \strong{IFI}: the Incremental Fit Index (IFI) adjusts the Normed Fit
+#'    \item **IFI**: the Incremental Fit Index (IFI) adjusts the Normed Fit
 #'    Index (NFI) for sample size and degrees of freedom (Bollen's, 1989). Over
 #'    0.90 is a good fit, but the index can exceed 1.
 #'
-#'    \item \strong{PNFI}: the Parsimony-Adjusted Measures Index. There is no
+#'    \item **PNFI**: the Parsimony-Adjusted Measures Index. There is no
 #'    commonly agreed-upon cutoff value for an acceptable model for this index.
 #'    Should be > 0.50. }
 #'
-#'    See the documentation for \code{?lavaan::fitmeasures}.
+#'    See the documentation for `?lavaan::fitmeasures`.
 #' }
 #'
 #' \subsection{What to report}{
 #' Kline (2015) suggests that at a minimum the following indices should be
-#' reported: The model \strong{chi-square}, the \strong{RMSEA}, the \strong{CFI}
-#' and the \strong{SRMR}.
+#' reported: The model **chi-square**, the **RMSEA**, the **CFI**
+#' and the **SRMR**.
 #' }
 #'
 #' @examples
@@ -147,3 +148,48 @@ model_performance.lavaan <- function(model, metrics = "all", verbose = TRUE, ...
   class(out) <- c("performance_lavaan", "performance_model", class(out))
   out
 }
+
+
+
+#' @export
+model_performance.blavaan <- function(model, metrics = "all", verbose = TRUE, ...) {
+  insight::check_if_installed(c("lavaan", "blavaan"))
+
+
+  if (isTRUE(verbose)) {
+    measures <- as.data.frame(t(as.data.frame(lavaan::fitmeasures(model, ...))))
+    fitind <- summary(blavaan::blavFitIndices(model))
+  } else {
+    measures <- as.data.frame(t(as.data.frame(suppressWarnings(lavaan::fitmeasures(model, ...)))))
+    fitind <- suppressWarnings(summary(blavaan::blavFitIndices(model)))
+  }
+
+  row.names(measures) <- NULL
+
+  out <- data.frame(
+    "BRMSEA" = fitind[1, "EAP"],
+    "SD_BRMSEA" = fitind[1, "SD"],
+    "BGammaHat" = fitind[2, "EAP"],
+    "SD_BGammaHat" = fitind[2, "SD"],
+    "Adj_BGammaHat" = fitind[3, "EAP"],
+    "SD_Adj_BGammaHat" = fitind[3, "SD"],
+    "Loglikelihood" = measures$logl,
+    "BIC" = measures$bic,
+    "DIC" = measures$dic,
+    "p_DIC" = measures$p_dic,
+    "WAIC" = measures$waic,
+    "SE_WAIC" = measures$se_waic,
+    "p_WAIC" = measures$p_waic,
+    "LOOIC" = measures$looic,
+    "SE_LOOIC" = measures$se_loo,
+    "p_LOOIC" = measures$p_loo
+  )
+
+  if (all(metrics == "all")) {
+    metrics <- names(out)
+  }
+  out <- out[, metrics]
+
+  class(out) <- c("performance_lavaan", "performance_model", class(out))
+  out
+}
