@@ -5,27 +5,28 @@
 #'   from a model with binary or count outcome.
 #'
 #' @param model Model with binary or count outcome.
+#' @param ... Arguments from other functions, usually only used internally.
 #' @inheritParams model_performance.lm
 #'
 #' @return A list with three elements, the logarithmic, quadratic/Brier and spherical score.
 #'
 #' @details Proper scoring rules can be used to evaluate the quality of model
-#' predictions and model fit. \code{performance_score()} calculates the logarithmic,
+#' predictions and model fit. `performance_score()` calculates the logarithmic,
 #' quadratic/Brier and spherical scoring rules. The spherical rule takes values
-#' in the interval \code{[0, 1]}, with values closer to 1 indicating a more
-#' accurate model, and the logarithmic rule in the interval \code{[-Inf, 0]},
+#' in the interval `[0, 1]`, with values closer to 1 indicating a more
+#' accurate model, and the logarithmic rule in the interval `[-Inf, 0]`,
 #' with values closer to 0 indicating a more accurate model.
 #' \cr \cr
-#' For \code{stan_lmer()} and \code{stan_glmer()} models, the predicted values
-#' are based on \code{posterior_predict()}, instead of \code{predict()}. Thus,
+#' For `stan_lmer()` and `stan_glmer()` models, the predicted values
+#' are based on `posterior_predict()`, instead of `predict()`. Thus,
 #' results may differ more than expected from their non-Bayesian counterparts
-#' in \strong{lme4}.
+#' in **lme4**.
 #'
 #' @references Carvalho, A. (2016). An overview of applications of proper scoring rules. Decision Analysis 13, 223–242. \doi{10.1287/deca.2016.0337}
 #'
-#' @note Code is partially based on \href{https://drizopoulos.github.io/GLMMadaptive/reference/scoring_rules.html}{GLMMadaptive::scoring_rules()}.
+#' @note Code is partially based on [GLMMadaptive::scoring_rules()](https://drizopoulos.github.io/GLMMadaptive/reference/scoring_rules.html).
 #'
-#' @seealso \code{\link[=performance_logloss]{performance_logloss()}}
+#' @seealso [`performance_logloss()`][performance_logloss]
 #'
 #' @examples
 #' ## Dobson (1990) Page 93: Randomized Controlled Trial :
@@ -49,13 +50,15 @@
 #' }
 #' }
 #' @export
-performance_score <- function(model, verbose = TRUE) {
+performance_score <- function(model, verbose = TRUE, ...) {
   # check special case
   if (inherits(model, c("logitor", "logitmfx", "probitmfx", "negbinirr", "negbinmfx", "poissonirr", "poissonmfx"))) {
     model <- model$fit
   }
 
-  minfo <- insight::model_info(model, verbose = verbose)
+  if (is.null(minfo <- list(...)$model_info)) {
+    minfo <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
 
   if (minfo$is_ordinal || minfo$is_multinomial) {
     if (verbose) insight::print_color("Can't calculate proper scoring rules for ordinal, multinomial or cumulative link models.\n", "red")
@@ -130,6 +133,46 @@ performance_score <- function(model, verbose = TRUE) {
 
 
 
+# methods -----------------------------------
+
+#' @export
+as.data.frame.performance_score <- function(x, row.names = NULL, ...) {
+  data.frame(
+    logarithmic = x$logarithmic,
+    quadratic = x$quadratic,
+    spherical = x$spherical,
+    stringsAsFactors = FALSE,
+    row.names = row.names,
+    ...
+  )
+}
+
+
+#' @export
+print.performance_score <- function(x, ...) {
+  # headline
+  insight::print_color("# Proper Scoring Rules\n\n", "blue")
+
+  results <- format(
+    c(
+      sprintf("%.4f", x$logarithmic),
+      sprintf("%.4f", x$quadratic),
+      sprintf("%.4f", x$spherical)
+    ),
+    justify = "right"
+  )
+
+  cat(sprintf("logarithmic: %s\n", results[1]))
+  cat(sprintf("  quadratic: %s\n", results[2]))
+  cat(sprintf("  spherical: %s\n", results[3]))
+
+  invisible(x)
+}
+
+
+
+# utilities ---------------------------------
+
 .dispersion_parameter <- function(model, minfo) {
   if (inherits(model, "MixMod")) {
     model$phis
@@ -185,16 +228,3 @@ performance_score <- function(model, verbose = TRUE) {
 
   list(pred = pred, pred_zi = pred_zi)
 }
-
-
-#' @export
-as.data.frame.performance_score <- function(x, row.names = NULL, ...) {
-  data.frame(
-    logarithmic = x$logarithmic,
-    quadratic = x$quadratic,
-    spherical = x$spherical,
-    stringsAsFactors = FALSE,
-    row.names = row.names,
-    ...
-  )
-}
