@@ -5,15 +5,15 @@
 #'  mixed effects models with complex random effects structures.
 #'
 #' @param model A mixed effects model.
-#' @param by_group Logical, if \code{TRUE}, returns the explained variance
+#' @param by_group Logical, if `TRUE`, returns the explained variance
 #'   at different levels (if there are multiple levels). This is essentially
 #'   similar to the variance reduction approach by \cite{Hox (2010), pp. 69-78}.
 #' @param tolerance Tolerance for singularity check of random effects, to decide
 #'   whether to compute random effect variances for the conditional r-squared
 #'   or not. Indicates up to which value the convergence result is accepted. When
-#'   \code{r2_nakagawa()} returns a warning, stating that random effect variances
-#'   can't be computed (and thus, the conditional r-squared is \code{NA}),
-#'   decrease the tolerance-level. See also \code{\link{check_singularity}}.
+#'   `r2_nakagawa()` returns a warning, stating that random effect variances
+#'   can't be computed (and thus, the conditional r-squared is `NA`),
+#'   decrease the tolerance-level. See also [check_singularity()].
 #'
 #' @return A list with the conditional and marginal R2 values.
 #'
@@ -21,7 +21,7 @@
 #'
 #' Marginal and conditional r-squared values for mixed models are calculated
 #' based on \cite{Nakagawa et al. 2017}. For more details on the computation of
-#' the variances, see \code{?insight::get_variance}.
+#' the variances, see `?insight::get_variance`.
 #'  \cr \cr
 #'  The marginal r-squared considers only the variance of the fixed effects,
 #'  while the conditional r-squared takes both the fixed and random effects into
@@ -102,7 +102,7 @@ r2_nakagawa <- function(model, by_group = FALSE, tolerance = 1e-5) {
     group_names <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
 
     # compute r2 by level
-    r2_random <- 1 - (vars$var.intercept / vars_null$var.intercept)
+    r2_random <- 1 - (vars$var.intercept[group_names] / vars_null$var.intercept[group_names])
     r2_fixed <- 1 - (vars$var.residual / vars_null$var.residual)
 
     out <- data.frame(
@@ -115,7 +115,7 @@ r2_nakagawa <- function(model, by_group = FALSE, tolerance = 1e-5) {
     out
   } else {
     # Calculate R2 values
-    if (.is_empty_object(vars$var.random) || is.na(vars$var.random)) {
+    if (insight::is_empty_object(vars$var.random) || is.na(vars$var.random)) {
       # if no random effect variance, return simple R2
       insight::print_color("Random effect variances not available. Returned R2 does not account for random effects.\n", "red")
       r2_marginal <- vars$var.fixed / (vars$var.fixed + vars$var.residual)
